@@ -1,3 +1,4 @@
+from PyQt5.QtCore import QSize
 from PyQt5.QtGui import QPalette
 from PyQt5.QtWidgets import QWidget, QHBoxLayout
 from pyqt_svg_button import SvgButton
@@ -109,4 +110,14 @@ class TitlebarButtonsWidget(QWidget):
         return self._helpBtn
 
     def setButtonIcon(self, hint: str, icon_filename: str):
-        self._btn_dict[hint].setIcon(icon_filename)
\ No newline at end of file
+        self._btn_dict[hint].setIcon(icon_filename)
+
+    def setButtonSize(self, w, h):
+        for k, v in self._btn_dict.items():
+            if v.text():
+                f = v.font()
+                f.setPointSize(w // 1.75)
+                v.setFont(f)
+            elif v.icon():
+                v.setIconSize(QSize(w, h))
+            v.setFixedSize(w, h)
